function [f_smooth W] = CTA_heat_smoothing(f, L, alpha, m, tol)

% CTA_heat_smoothing smoothes a function defined 
% in non-Euclidean space (i.e., Graph) using heat-kernel
% 
% Input: 
%   f: function defined on each vertex
%   L: graph Laplacian
%   m: order of Chebychev approximation
%   K, alph: kernel defining parameter
%   tol: tolerance for Conjugate Gradients in inverse transform
%
% Output: 
%   f_smooth: smoothed function
%   W: transform coefficients
%
% Coded by Won Hwa Kim, 2013
% Dept. of Computer Sciences, University of Wisconsin

if nargin < 3
    error('Invalid input numbers.');
elseif nargin < 4
    m = 50;
    tol = 1e-3;    
elseif nargin == 4
    tol = 1e-3;    
end

J=0;
Nscales = J+1;
lmax = sgwt_rough_lmax(L);
arange = [0 lmax];

%designtype = 'heat_kernel';
%[g,t]=sgwt_filter_design_param(lmax,J,'designtype',designtype,'lpfactor',K,'alph',alph);

g{1} = CTA_heat_kernel_design(alpha);
c{1}=sgwt_cheby_coeff(g{1},m,m+1,arange);

W=sgwt_cheby_op(f,L,c,arange);

f_smooth = sgwt_inverse(W,L,c,arange, 'tol', tol);
