function [surf, sphere, signal] = CTA_load_surf(dir, subject, rl)

% function CTA_loadsurf loads a brain surface and cortical thickness values
%
% Input: 
%	dir: dataset directory
%	subject: subject id
%	rl: 'right' or 'left' hemisphere
%
% Output: 
%	surf: brain surface model
%	sphere: sphere surface model
%	signal: cortical thickness values
%
% Coded by Won Hwa Kim, 2013
% Dept. of Computer Sciences, University of Wisconsin
%


switch(rl)
    case 'right'
        side = 'rh';
    case 'left'
        side = 'lh';
    otherwise
        disp('wrong side of the brain');
end

mesh = strcat(dir, subject, '/surf/', side, '.pial');
signal_file = strcat(dir, subject, '/surf/', side, '.thickness');
sphere_mesh = strcat(dir, subject, '/surf/', side,'.sphere');

[vertices, faces] = read_surf(mesh);
surf.vertices=vertices;
surf.faces=faces+1;
%thickness = load(signal_dir);
%signal = thickness(:,5);
signal = read_curv(signal_file);

[vertices2, faces2] = read_surf(sphere_mesh);
sphere.vertices=vertices2;
sphere.faces=faces2+1;
