function [D, L, evec, eval] = CTA_spectralgraph(A, d)
%
% function CTA_spectralgraph finds degree matrix and graph Laplacian matrix. 
%
% Input: 
%	A: adjacency matrix
%	d: # of smallest eigenvalues to find
%
% Output: 
%	D: degree matrix
%	L: graph Laplacian
%	evec: eigenvectors
%	eval: eigenvalues
% 
% If 'd' is not provided, it will return 0s for eval and evec.
%
% Coded by Won Hwa Kim, 2013
% Dept. of Computer Sciences, University of Wisconsin
%

A = sparse(A);
diagonal = sum(A);
D = diag(diagonal);
L = D-A;

if nargin == 1
    evec = 0;
    eval = 0;

else
    [evec eval] = eigs(L, d, 'sm');
    eval = sum(eval);
end
