function [p_sort, idx, max_k, thres, thr] = FDR(p, alph)
%
% Function FDR processes False Discovery Rate on multiple comparison correction on p-values.
% 
% Input: 
%     p: nx1 vector of p-values (n number of tests)
%     alph: rate for threshold level (ex: 0.05)
%         
% Output:
%     p_sort: sorted p-values
%     idx: original index of p_sort
%     max_k: number of voxels that survives the procedure
%     thres: threshold at each level 
%     thr: largest threshold 
%     
% Won Hwa Kim, wonhwa@cs.wisc.edu
% Last updated: 2013. 4. 25
%

max_k = 0;
[p_sort, idx] = sort(p);
m = length(p);
thres = zeros(m,1);

for k=1:m
    p_k = p_sort(k);
    thres(k) = alph * k/m;
    
    if(p_k < thres(k));        
        max_k = k;
    end
end

if max_k ~= 0
    thr = thres(max_k);
else
    thr = 0;
end

fprintf('max k = %d\n', max_k);
